@@ -16,7 +16,7 @@ class IterableObject(object):
     look like an object but with the power of being iterable.
     """
     def __init__(self, source):
-        self.source=source
+        object.__setattr__(self, 'source', source)
 
     def __iter__(self):
         return self.source.iteritems()
@@ -27,9 +27,18 @@ class IterableObject(object):
 
         return self.source[key]
 
+    def __setattr__(self, key, value):
+        if isinstance(value, dict) or isinstance(value, list):
+            value=DictionaryUtility.to_object(value)
+        
+        self.source[key]=value
+
     def __getitem__(self, key):
         return self.source[key]
 
+    def __setitem__(self, key, value):
+        self.__setattr__(key, value)
+
     def __contains__(self, key):
         return key in self.source
     
